summaryrefslogtreecommitdiffstats
path: root/kdat/Archive.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdat/Archive.h')
-rw-r--r--kdat/Archive.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/kdat/Archive.h b/kdat/Archive.h
index 7527073..9f42684 100644
--- a/kdat/Archive.h
+++ b/kdat/Archive.h
@@ -39,7 +39,7 @@ class Archive {
FILE* _fptr;
int _offset;
TQString _name;
- TQPtrList<File> _tqchildren;
+ TQPtrList<File> _children;
RangeList _ranges;
Tape* _tape;
public:
@@ -67,7 +67,7 @@ public:
Archive( Tape* tape, FILE* fptr, int offset );
/**
* Destroy the archive entry and all of its tqchildren.
*/
~Archive();
@@ -82,7 +82,7 @@ public:
/**
* Recursively read the instance data for this archive entry and all of its
* tqchildren. This method is used when converting from an older index format.
*
* @param version The version of the old tape index.
*/
@@ -90,7 +90,7 @@ public:
/**
* Write out the archive entry to the open file. Entries for each of its
* tqchildren will also be written.
*/
void write( FILE* fptr );
@@ -125,12 +125,12 @@ public:
/**
* Get the list of top-level files in this archive.
*
* @return A list of the immediate tqchildren of this archive.
*/
const TQPtrList<File>& getChildren();
/**
* Get the list of ranges of this file and all of its tqchildren.
*
* @return A list of ranges.
*/
@@ -176,7 +176,7 @@ public:
File* addFile( int size, int mtime, int startRecord, int endRecord, const TQString & filename );
/**
* Recursively calculate the list of ranges for all of the archive's tqchildren.
*/
void calcRanges();
};
@@ -67,7 +67,7 @@ public:
Archive( Tape* tape, FILE* fptr, int offset );
/**
- * Destroy the archive entry and all of its tqchildren.
+ * Destroy the archive entry and all of its children.
*/
~Archive();
@@ -82,7 +82,7 @@ public:
/**
* Recursively read the instance data for this archive entry and all of its
- * tqchildren. This method is used when converting from an older index format.
+ * children. This method is used when converting from an older index format.
*
* @param version The version of the old tape index.
@@ -90,7 +90,7 @@ public:
/**
* Write out the archive entry to the open file. Entries for each of its
- * tqchildren will also be written.
+ * children will also be written.
*/
void write( FILE* fptr );
@@ -125,12 +125,12 @@ public:
* Get the list of top-level files in this archive.
*
- * @return A list of the immediate tqchildren of this archive.
+ * @return A list of the immediate children of this archive.
*/
const TQPtrList<File>& getChildren();
@@ -125,12 +125,12 @@ public:
const TQPtrList<File>& getChildren();
/**
- * Get the list of ranges of this file and all of its tqchildren.
+ * Get the list of ranges of this file and all of its children.
*
* @return A list of ranges.
@@ -176,7 +176,7 @@ public:
File* addFile( int size, int mtime, int startRecord, int endRecord, const TQString & filename );
/**
- * Recursively calculate the list of ranges for all of the archive's tqchildren.
+ * Recursively calculate the list of ranges for all of the archive's children.
*/
void calcRanges();